.. _modules-node_attributes:

#################
 Node attributes
#################

.. automodule:: anemoi.graphs.nodes.attributes.area_weights
   :members:
   :exclude-members: AreaWeights
   :no-undoc-members:
   :show-inheritance:

.. automodule:: anemoi.graphs.nodes.attributes.masks
   :members:
   :exclude-members: BaseCombineAnemoiDatasetsMask
   :no-undoc-members:
   :show-inheritance:

.. automodule:: anemoi.graphs.nodes.attributes.boolean_op
   :members:
   :exclude-members: BooleanOperation
   :no-undoc-members:
   :show-inheritance:
